<svg xmlns="http://www.w3.org/2000/svg" class="h-{{ size|default:'4' }} w-{{ size|default:'4' }} float-left" fill="none" viewBox="0 0 24 24"
     stroke="currentColor">
    <path stroke-linecap="round" stroke-linejoin="round" stroke-width="2"
          d="M12 6v6m0 0v6m0-6h6m-6 0H6"/>
</svg>