{% extends get_master_template %}
{% load static i18n %}

{% block extra_css %}
    <link rel="stylesheet" href="{% static 'djf_surveys/te-starter/css/tw-elements.min.css' %}">
{% endblock %}

{% block content %}
    <div class="container px-5 lg:py-32 sm:py-16">
        <div class="relative p-8 text-center border border-gray-200 rounded-lg">
            <div class="flex justify-center">
            <svg xmlns="http://www.w3.org/2000/svg" x="0px" y="0px" width="100" height="100" viewBox="0 0 48 48">
                    <path fill="#4caf50" d="M44,24c0,11.045-8.955,20-20,20S4,35.045,4,24S12.955,4,24,4S44,12.955,44,24z"></path><path fill="#ccff90" d="M34.602,14.602L21,28.199l-5.602-5.598l-2.797,2.797L21,33.801l16.398-16.402L34.602,14.602z"></path>
                    </svg>
            </div>
            <h1 class="text-3xl pb-6 font-medium">
               {% trans 'Thank you for completing this survey' %}
            </h1>
            <p class="mt-4 text-sm text-gray-500">
                {% if object.success_page_content %}
                    {{ object.success_page_content|safe }}
                {% else %}
                    {% trans "I really appreciate your effort and the time you devoted to filling the questionnaire. Your answers will help us." %}
                {% endif %}
            </p>

            <div class="flex justify-center py-6">
                <a href="{{ link_back_on_success_page }}" class="block mt-5 px-5 py-3 text-sm font-medium text-white bg-blue-500 rounded-lg">
                    {% trans "Back" %}
                </a>
            </div>
        </div>
    </div>
{% endblock %}